<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Http\Controllers\Admin;
use Illuminate\Http\Request;
use App\Http\Helper\Helper;
use Illuminate\Support\Facades\Hash;
use App\Managers\Schedule\ScheduleManager;
use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use App\Managers\Player\PlayerManager;
use App\Managers\Tactics\TacticsManager;
use App\Managers\FormationPositions\FormationPositionsManager;
use App\Managers\TacticContainer\TacticContainerManager;

class AdminReportsController extends Controller
{
    public function __construct()
    {
        $this->helper = new Helper();
        $this->scheduleManager = new ScheduleManager();
        $this->playerManager = new PlayerManager();
        $this->tacticsManager = new TacticsManager();
        $this->formationPosition = new FormationPositionsManager();
        $this->tacticContainer = new TacticContainerManager();
    }
    
    public function getPlayerEvaluationList()
    {
        $schedules = $this->scheduleManager->with('opposite_team_det')->get();
        return view('/admin/reports/player_evaluation_list')->with('schedules', $schedules);
    }
    
    public function getTacticList()
    {
        $schedules = $this->scheduleManager->with('opposite_team_det')->get();
        return view('/admin/reports/tactic_list')->with('schedules', $schedules);
    }
    
    public function getPlayerEvaluationReport($UUID)
    {
        $players = $this->playerManager->with('playerPosition')->orderBy('name')->get();
        return view('admin/reports/player_evaluation_report')->with('players', $players)->with('UUID', $UUID);
    }
    
    public function getTacticsReport($UUID)
    {
        return view('admin/reports/tactics_report')->with('UUID', $UUID);
    }
    
    public function tacticResultsJson(Request $request)
    {
        if(!$request->exists('positions'))
        {
            return response()->json([], 201);
        }
        if(!$request->exists('scheduleID'))
        {
            return response()->json(['Schedule ID not found'], 400);
        }
        
        $scheduleID = $request->get('scheduleID');
        $positions = $request->get('positions');
        $playerPoints = array();
        $playerPositions = array();
        $count1 = 0;
        
        $formation = $this->scheduleManager->getCurrentMatchPreFormation($request->get('scheduleID'));
        $formationID = $formation->formation_id;
        
        $count2 = 0;
        foreach($positions AS $position => $count)
        {
            $playerPoint = $this->tacticsManager->getHighesValuePlayer($position, $count, $scheduleID);
            
            $count = 0;
            if($playerPoint->count() > 0)
            {
                $positionColumns = $this->formationPosition->getCurrentFormationPositionColumnOfPosition($playerPoint[0]->position_id, $formationID);
                $columnsArray = array();
                $playersArray = array();
                foreach($playerPoint AS $each1)
                {
                    
                    foreach($positionColumns AS $column)
                    {
                        if(!in_array($column->column_count, $columnsArray) && !in_array($each1->UUID, $playersArray))
                        {
                            $playerPositions[$count2]['name'] = $each1->name;
                            $playerPositions[$count2]['photo'] = $each1->photo;
                            $playerPositions[$count2]['position_columns_id'] = $column->column_count;
                            $playerPositions[$count2]['votes'] = $this->tacticsManager->getCurrentTacticsPlayerVotes($each1->UUID, $scheduleID, $each1->position_id)->vote_count;
                            $columnsArray[] = $column->column_count;
                            $playersArray[] = $each1->UUID;
                                    
                            $count2++;
                        }
                    }
                    
                }
                
            }
        }
        

        $res = array();
        $res['response1'] = $playerPositions;
        $res['captainCount'] = $this->tacticContainer->getHighestVotedCaptain($scheduleID);
        $res['freekickCount'] = $this->tacticContainer->getHighestVotedFreeKick($scheduleID);
        
        $res['cornerCount'] = $this->tacticContainer->getHighestVotedCorner($scheduleID);
        $res['penaltyCount'] = $this->tacticContainer->getHighestVotedPenalty($scheduleID);
        
        $res['str1'] = $this->tacticContainer->getHighestVotedStr1($scheduleID);
        $res['str2'] = $this->tacticContainer->getHighestVotedStr2($scheduleID);
        
        return response()->json($res,200);
    }
    
}